summaryrefslogtreecommitdiffstats
path: root/lib/kotext/KoTextFormatter.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:31 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:31 -0600
commitc9cb4f487428aad5d8cda5e3a4b9ad87390d7e54 (patch)
tree1ee1912ac4bb966475f0db0f2a78678661b4b4a5 /lib/kotext/KoTextFormatter.cpp
parent94844816550ad672ccfcdc25659c625546239998 (diff)
downloadkoffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.tar.gz
koffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 94844816550ad672ccfcdc25659c625546239998.
Diffstat (limited to 'lib/kotext/KoTextFormatter.cpp')
-rw-r--r--lib/kotext/KoTextFormatter.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/lib/kotext/KoTextFormatter.cpp b/lib/kotext/KoTextFormatter.cpp
index 552bcf27..7bdfbc0c 100644
--- a/lib/kotext/KoTextFormatter.cpp
+++ b/lib/kotext/KoTextFormatter.cpp
@@ -131,8 +131,8 @@ int KoTextFormatterCore::leftMargin( bool firstLine, bool includeFirstLineMargin
left += parag->firstLineMargin();
// Add the width of the paragraph counter - first line of parag only.
if( parag->counter() &&
- ( parag->counter()->alignment() == TQt::AlignLeft ||
- parag->counter()->alignment() == TQt::AlignAuto ) )
+ ( parag->counter()->tqalignment() == TQt::AlignLeft ||
+ parag->counter()->tqalignment() == TQt::AlignAuto ) )
left += parag->counterWidth(); // in LU pixels
}
return left;
@@ -196,7 +196,7 @@ bool KoTextFormatterCore::format()
// but with counters/margins this might be different). This is why
// we call determineCharWidth() again from within the loop.
TQPair<int, int> widths = determineCharWidth();
- int ww = widths.first; // width in layout units
+ int ww = widths.first; // width in tqlayout units
#ifndef REF_IS_LU
int pixelww = widths.second; // width in pixels
#endif
@@ -251,9 +251,9 @@ bool KoTextFormatterCore::format()
bool lastWasNonInlineCustom = FALSE;
bool abort = false;
- int align = parag->alignment();
- if ( align == TQt::AlignAuto && doc && doc->alignment() != TQt::AlignAuto )
- align = doc->alignment();
+ int align = parag->tqalignment();
+ if ( align == TQt::AlignAuto && doc && doc->tqalignment() != TQt::AlignAuto )
+ align = doc->tqalignment();
int col = 0;
@@ -516,11 +516,11 @@ bool KoTextFormatterCore::format()
spaceAfterLine -= c->width;
//else
- if ( c->c.unicode() == 0xad || hyphenated ) // soft hyphen or hyphenation
+ if ( c->c.tqunicode() == 0xad || hyphenated ) // soft hyphen or hyphenation
{
// Recalculate its width, the hyphen will appear finally (important for the parag rect)
int width = KoTextZoomHandler::ptToLayoutUnitPt( c->format()->refFontMetrics().width( TQChar(0xad) ) );
- if ( c->c.unicode() == 0xad )
+ if ( c->c.tqunicode() == 0xad )
c->width = width;
spaceAfterLine -= width;
}
@@ -810,7 +810,7 @@ KoTextParagLineStart *KoTextFormatterCore::koFormatLine(
if (space < 0)
space = 0;
// do alignment Auto == Left in this case
if ( align & TQt::AlignHCenter || align & TQt::AlignRight ) {
if ( align & TQt::AlignHCenter )
space /= 2;
@@ -934,7 +934,7 @@ KoTextParagLineStart *KoTextFormatterCore::koBidiReorderLine(
str.setUnicode( 0, last - start + 1 );
// fill string with logically ordered chars.
KoTextStringChar *ch = startChar;
- TQChar *qch = (TQChar *)str.unicode();
+ TQChar *qch = (TQChar *)str.tqunicode();
while ( ch <= lastChar ) {
*qch = ch->c;
qch++;
@@ -949,7 +949,7 @@ KoTextParagLineStart *KoTextFormatterCore::koBidiReorderLine(
// now construct the reordered string out of the runs...
int numSpaces = 0;
// set the correct alignment. This is a bit messy....
if( align == TQt::AlignAuto ) {
// align according to directionality of the paragraph...
if ( text->isRightToLeft() )
@@ -810,7 +810,7 @@ KoTextParagLineStart *KoTextFormatterCore::koFormatLine(
if (space < 0)
space = 0;
- // do alignment Auto == Left in this case
+ // do tqalignment Auto == Left in this case
if ( align & TQt::AlignHCenter || align & TQt::AlignRight ) {
if ( align & TQt::AlignHCenter )
@@ -949,7 +949,7 @@ KoTextParagLineStart *KoTextFormatterCore::koBidiReorderLine(
// now construct the reordered string out of the runs...
int numSpaces = 0;
- // set the correct alignment. This is a bit messy....
+ // set the correct tqalignment. This is a bit messy....
if( align == TQt::AlignAuto ) {
// align according to directionality of the paragraph...